@@ -18,24 +18,29 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
+"""Module for Harmony One address computation."""
 
 # Imports
 from typing import Any, Union
 from bip_utils.addr.iaddr_encoder import IAddrEncoder
 from bip_utils.addr.eth_addr import EthAddr
 from bip_utils.bech32 import Bech32Encoder
-from bip_utils.coin_conf import HarmonyOneConf
+from bip_utils.coin_conf import CoinsConf
 from bip_utils.ecc import IPublicKey
 from bip_utils.utils.misc import ConvUtils
 
 
 class OneAddr(IAddrEncoder):
-    """ Harmony One address class. It allows the Harmony One address generation. """
+    """
+    Harmony One address class.
+    It allows the Harmony One address generation.
+    """
 
     @staticmethod
     def EncodeKey(pub_key: Union[bytes, IPublicKey],
                   **kwargs: Any) -> str:
-        """ Get address in Harmony One format.
+        """
+        Get address in Harmony One format.
 
         Args:
             pub_key (bytes or IPublicKey): Public key bytes or object
@@ -53,5 +58,5 @@ class OneAddr(IAddrEncoder):
         eth_addr = EthAddr.EncodeKey(pub_key)[2:]
 
         # Encode in Bech32 format
-        return Bech32Encoder.Encode(HarmonyOneConf.ADDR_HRP,
+        return Bech32Encoder.Encode(CoinsConf.HarmonyOne.Params("addr_hrp"),
                                     ConvUtils.HexStringToBytes(eth_addr))
