@@ -1,5 +1,4 @@
 from bip_utils.bech32.bech32_ex import Bech32ChecksumError, Bech32FormatError
-from bip_utils.bech32.atom_bech32 import AtomBech32Decoder, AtomBech32Encoder
-from bip_utils.bech32.avax_bech32 import AvaxChainTypes, AvaxBech32Decoder, AvaxBech32Encoder
 from bip_utils.bech32.bch_bech32 import BchBech32Decoder, BchBech32Encoder
+from bip_utils.bech32.bech32 import Bech32Decoder, Bech32Encoder
 from bip_utils.bech32.segwit_bech32 import SegwitBech32Decoder, SegwitBech32Encoder
