@@ -32,7 +32,7 @@ from bip_utils.bip.bip39.bip39_ex import Bip39ChecksumError
 from bip_utils.bip.bip39.bip39_entropy_generator import Bip39EntropyGenerator
 from bip_utils.utils.misc import ConvUtils, CryptoUtils
 from bip_utils.utils.mnemonic import (
-    MnemonicLanguages, Mnemonic, MnemonicWordsList, MnemonicWordsListGetterBase
+    Mnemonic, MnemonicLanguages, MnemonicWordsList, MnemonicWordsListGetterBase
 )
 
 
