@@ -44,13 +44,18 @@ class Bip44ConfGetterConst:
         Bip44Coins.BITCOIN_TESTNET: Bip44Conf.BitcoinTestNet,
         Bip44Coins.BITCOIN_CASH: Bip44Conf.BitcoinCashMainNet,
         Bip44Coins.BITCOIN_CASH_TESTNET: Bip44Conf.BitcoinCashTestNet,
+        Bip44Coins.BITCOIN_CASH_SLP: Bip44Conf.BitcoinCashSlpMainNet,
+        Bip44Coins.BITCOIN_CASH_SLP_TESTNET: Bip44Conf.BitcoinCashSlpTestNet,
         Bip44Coins.BITCOIN_SV: Bip44Conf.BitcoinSvMainNet,
         Bip44Coins.BITCOIN_SV_TESTNET: Bip44Conf.BitcoinSvTestNet,
+        Bip44Coins.CELO: Bip44Conf.Celo,
         Bip44Coins.COSMOS: Bip44Conf.Cosmos,
         Bip44Coins.DASH: Bip44Conf.DashMainNet,
         Bip44Coins.DASH_TESTNET: Bip44Conf.DashTestNet,
         Bip44Coins.DOGECOIN: Bip44Conf.DogecoinMainNet,
         Bip44Coins.DOGECOIN_TESTNET: Bip44Conf.DogecoinTestNet,
+        Bip44Coins.ECASH: Bip44Conf.EcashMainNet,
+        Bip44Coins.ECASH_TESTNET: Bip44Conf.EcashTestNet,
         Bip44Coins.ELROND: Bip44Conf.Elrond,
         Bip44Coins.EOS: Bip44Conf.Eos,
         Bip44Coins.ETHEREUM: Bip44Conf.Ethereum,
