@@ -1,3 +1,3 @@
 from bip_utils.bip.conf.bip49.bip49_coins import Bip49Coins
-from bip_utils.bip.conf.bip49.bip49_conf import *
+from bip_utils.bip.conf.bip49.bip49_conf import Bip49Conf
 from bip_utils.bip.conf.bip49.bip49_conf_getter import Bip49ConfGetter
