@@ -37,12 +37,16 @@ class Bip49ConfGetterConst:
         Bip49Coins.BITCOIN_TESTNET: Bip49Conf.BitcoinTestNet,
         Bip49Coins.BITCOIN_CASH: Bip49Conf.BitcoinCashMainNet,
         Bip49Coins.BITCOIN_CASH_TESTNET: Bip49Conf.BitcoinCashTestNet,
+        Bip49Coins.BITCOIN_CASH_SLP: Bip49Conf.BitcoinCashSlpMainNet,
+        Bip49Coins.BITCOIN_CASH_SLP_TESTNET: Bip49Conf.BitcoinCashSlpTestNet,
         Bip49Coins.BITCOIN_SV: Bip49Conf.BitcoinSvMainNet,
         Bip49Coins.BITCOIN_SV_TESTNET: Bip49Conf.BitcoinSvTestNet,
         Bip49Coins.DASH: Bip49Conf.DashMainNet,
         Bip49Coins.DASH_TESTNET: Bip49Conf.DashTestNet,
         Bip49Coins.DOGECOIN: Bip49Conf.DogecoinMainNet,
         Bip49Coins.DOGECOIN_TESTNET: Bip49Conf.DogecoinTestNet,
+        Bip49Coins.ECASH: Bip49Conf.EcashMainNet,
+        Bip49Coins.ECASH_TESTNET: Bip49Conf.EcashTestNet,
         Bip49Coins.LITECOIN: Bip49Conf.LitecoinMainNet,
         Bip49Coins.LITECOIN_TESTNET: Bip49Conf.LitecoinTestNet,
         Bip49Coins.ZCASH: Bip49Conf.ZcashMainNet,
